summaryrefslogtreecommitdiffstats
path: root/win/tclWinInit.c
diff options
context:
space:
mode:
Diffstat (limited to 'win/tclWinInit.c')
-rw-r--r--win/tclWinInit.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/win/tclWinInit.c b/win/tclWinInit.c
index 0dadc24..11d182a 100644
--- a/win/tclWinInit.c
+++ b/win/tclWinInit.c
@@ -607,9 +607,10 @@ TclpSetVariables(
*
* Results:
* The return value is the index in environ of an entry with the name
* "name", or (size_t)-1 if there is no such entry. The integer at *lengthPtr is
* filled in with the length of name (if a matching entry is found) or
* the length of the environ array (if no matching entry is found).
*
* Side effects:
* None.
@@ -626,7 +627,7 @@ TclpFindVariable(
* entries in environ (for unsuccessful
* searches). */
{
- size_t i, length, result = (size_t)-1;
+ size_t i, length, result = TCL_IO_FAILURE;
register const char *env, *p1, *p2;
char *envUpper, *nameUpper;
Tcl_DString envString;
@@ -607,9 +607,10 @@ TclpSetVariables(
* Results:
* The return value is the index in environ of an entry with the name
- * "name", or (size_t)-1 if there is no such entry. The integer at *lengthPtr is
- * filled in with the length of name (if a matching entry is found) or
- * the length of the environ array (if no matching entry is found).
+ * "name", or TCL_IO_FAILURE if there is no such entry. The integer
+ * at *lengthPtr is filled in with the length of name (if a matching
+ * entry is found) or the length of the environ array (if no
+ * matching entry is found).
*
* Side effects: